import asyncpg
import io
import os

import logging
import tornado
import tornado.web
from tornado.log import enable_pretty_logging
from functools import partial
import mercantile
import pyproj
import yaml
import sys
import itertools

log = logging.getLogger('tornado.application')

def GetTM2Source(file):
    with open(file,'r') as stream:
        tm2source = yaml.load(stream)
    return tm2source

dsn = 'postgresql://'+os.getenv('POSTGRES_USER','openmaptiles')+':'+os.getenv('POSTGRES_PASSWORD','openmaptiles')+'@'+os.getenv('POSTGRES_HOST','postgres')+':'+os.getenv('POSTGRES_PORT','5432')+'/'+os.getenv('POSTGRES_DB','openmaptiles')


class GetTile(tornado.web.RequestHandler):
    def initialize(self, pool):
        self.pool = pool

    async def get(self, zoom,x,y):
        self.set_header("Content-Type", "application/x-protobuf")
        self.set_header("Content-Disposition", "attachment")
        self.set_header("Access-Control-Allow-Origin", "*")
        async with self.pool.acquire() as connection:
            tile = await connection.fetchval("SELECT gettile($1, $2, $3)", int(zoom), int(x), int(y))
            self.write(tile)

def m():
    enable_pretty_logging()
    io_loop = tornado.ioloop.IOLoop.current()
    pool = io_loop.run_sync(partial(asyncpg.create_pool, dsn=dsn))
    application = tornado.web.Application([(r"/tiles/([0-9]+)/([0-9]+)/([0-9]+).pbf", GetTile, dict(pool=pool))])
    print("Postserve started..")
    application.listen(int(os.getenv("LISTEN_PORT", "8080")))
    io_loop.start()

if __name__ == "__main__":
    m()
